/* DIR.PRG - Directory functions

   DirParse() allows you to extract the drive, directory, name, and
   extension from a directory/filename combination. DirParseError() returns
   an error description of the last error or of the optional error number
   passed. Below is an example:

   IF ( DirParse( cFileDir, @cDrive, @cDir, @cName, @cExt ) > 0 )
      ? DirParseError()
   ELSE
      ? "Drive:     ", cDrive
      ? "Directory: ", cDir
      ? "File Name: ", cName
      ? "Extension: ", cExt
   ENDIF

*/
STATIC nErrorNo:= 0
//......................................................
FUNCTION DirParse( cFileDir, cDrive, cDir, cName, cExt )
LOCAL nColonPos:= At( ":", cFileDir),;
      nSlashPos:= RAt( "\", cFileDir),;
      nPeriodPos:= RAt( ".", cFileDir)
   nErrorNo:= 0                   // Start with no error and
   cDrive:= cDir:= cName:= ""     // with em all blank.
   BEGIN SEQUENCE

      // Work the colon
      DO CASE
      CASE ( nColonPos == 2 )
         cDrive:= Left( cFileDir, 2 )
         IF !IsAlpha( cDrive )
            nErrorNo:= 1                  // Invalid Drive Letter
            BREAK
         ENDIF

      CASE ( nColonPos <> 0 )
         nErrorNo:= 2                     // Invalid Colon position
         BREAK
      ENDCASE

      // Work the backslash
      IF ( nSlashPos > 0 )
         cDir:= SubStr( cFileDir, nColonPos+1, nSlashPos-nColonPos )
      ENDIF

      // Work the period
      IF ( nPeriodPos == 0 ) .OR. ( nPeriodPos < nSlashPos )
         nPeriodPos:= Len( cFileDir+= "." )
      ELSE
         cExt:= SubStr( cFileDir, nPeriodPos+1 )
      ENDIF

      // Work the name
      cName:= SubStr( cFileDir, nSlashPos+1, Min( 8, nPeriodPos-nSlashPos-1 ) )
      IF ( Len( cName ) == 0 )
         nErrorNo:= 3                     // Empty File Name
         BREAK
      ENDIF

   END SEQUENCE
RETURN( nErrorNo )

//......................................................
FUNCTION DirParseError( nErrNo )
RETURN( { "",;
          "Invalid Drive Letter",;
          "Invalid Colon position",;
          "Empty File Name" } [ IIf( nErrNo==NIL, nErrorNo, nErrNo ) + 1 ] )

//......................................................
FUNCTION DirTmp()
STATIC cTmpDir:= NIL
LOCAL nError:= 0, cDrive, cDir
   IF ( cTmpDir == NIL )
      IF ( nError := DirParse( SysCfgGet("TMP"), @cDrive, @cDir ) ) == 3
         cTmpDir:= cDrive+cDir
      ELSE
         cTmpDir:= ""
      ENDIF
   ENDIF
RETURN( cTmpDir )

//......................................................
FUNCTION DirTables()    // Returns a valid directory for data tables
STATIC cTableDir:= NIL
LOCAL nError:= 0, cDrive, cDir:= ""
   IF ( cTableDir == NIL )
      IF Empty( cDir:= SysCfgGet("TABLEDIR") )
         cDir:= SysCfgGet("DATADIR")
      ENDIF
      IF ( nError := DirParse( cDir, @cDrive, @cDir ) ) == 3
         cTableDir:= cDrive+cDir
      ELSE
         cTableDir:= ""
      ENDIF
   ENDIF
RETURN( cTableDir )

//......................................................
FUNCTION DirIndexes()      // Returns a valid directory for indexes
STATIC cTableDir:= NIL
LOCAL nError:= 0, cDrive, cDir:= ""
   IF ( cTableDir == NIL )
      IF Empty( cDir:= SysCfgGet("INDEXDIR") )
         cDir:= SysCfgGet("DATADIR")
      ENDIF
      IF ( nError := DirParse( cDir, @cDrive, @cDir ) ) == 3
         cTableDir:= cDrive+cDir
      ELSE
         cTableDir:= ""
      ENDIF
   ENDIF
RETURN( cTableDir )

//......................................................
// EOF: DIR.PRG
